==> telegram-bot-node-0.1.7.tgz: package/lib/message-controller.js <==
var inherit = require('inherit');
var path = require('path');
var fs = require('fs');

// Types of message.
var MESSAGE_TYPES = require('./consts/message-types');

/**
 * @class
 * @name MessageController
 */
var MessageController = inherit({
    /**
     * @param {TelegramBot} bot
     * @param {String|IPlugin} [plugins]
     */
    __constructor: function (bot, plugins) {
        plugins = plugins || [];

        this._bot = bot;
        this._plugins = {};

        // Get all plugins from folder (recursive).
        var pluginsList = typeof plugins === 'string' ?
            getPlugins(plugins) :
            plugins;

        pluginsList.forEach(function (plugin) {
            var category = this._plugins[plugin.type];
            if (Array.isArray(category)) {
                category.push(plugin);
            } else {
                this._plugins[plugin.type] = [plugin];
            }
        }, this);
    },

    /**
     * @param {Object} data Information about the message from analyzers.
     * @returns {Promise}
     */
    process: function (data) {
        var bot = this._bot;
        var message = bot.getCurrentMessage();
        var plugins = this._plugins;
        var pluginsCategory = [].concat(plugins[data.type], plugins[MESSAGE_TYPES.ALL]).filter(Boolean);
        var information = {
            message: message,
            data: data
        };

        // If plugins not found in category.
        if (!pluginsCategory.length) {
            return;
        }

        var plugin = pluginsCategory
            .filter(function (plugin) {
                var isCommand = data.type === MESSAGE_TYPES.COMMAND;
                // If we have bot name and get message in group chat like this:
                // `/start@myBot` -> we should not react on the message if bot name is not `myBot`.
                if (isCommand && data.commandFor && bot.getName()) {
                    return data.commandFor === bot.getName() && plugin.test(information);
                } else {
                    return plugin.test(information);
                }
            })
            .sort(function (a, b) {
                var aWeight = a.weight || 0;
                var bWeight = b.weight || 0;

                return b.weight - a.weight;
            })[0];

        // If we doesn't have plugins, which match the message.
        if (!plugin) {
            return;
        }

        // Run plugin.
        if (!bot.getUsersCollection()) {
            plugin.handler(information, bot);
        } else {
            bot.user.get().then(function (user) {
                information.user = user;
                plugin.handler(information, bot);
            });
        }
    }
});

/**
 * @ignore
 * @param {String} pluginsDir
 * @param {IPlugin[]} [plugins=[]]
 * @returns {IPlugins[]} All plugins from `pluginsDir` folder.
 */
function getPlugins(pluginsDir, plugins) {
    plugins = plugins || [];
    fs.readdirSync(pluginsDir)
        .forEach(function (item) {
            var itemPath = path.resolve(pluginsDir, item);
            var stats = fs.statSync(itemPath);

            if (stats.isDirectory()) {
                getPlugins(itemPath, plugins);
            } else {
                var itemExtension = item.split('.').pop();
                if (itemExtension === 'js') {
                    plugins.push(require(itemPath));
                }
            }
        });

    return plugins;
}

module.exports = MessageController;

==> telegram-bot-node-0.2.2.tgz: package/lib/message-controller.js <==
var inherit = require('inherit');
var vow = require('vow');
var path = require('path');
var fs = require('fs');

// Types of message.
var MESSAGE_TYPES = require('./consts/message-types');

/**
 * @class
 * @name MessageController
 */
var MessageController = inherit({
    /**
     * @param {TelegramBot} bot
     * @param {String|IPlugin} [plugins]
     */
    __constructor: function (bot, plugins) {
        plugins = plugins || [];

        this._bot = bot;
        this._plugins = {};

        // Get all plugins from folder (recursive).
        var pluginsList = typeof plugins === 'string' ?
            getPlugins(plugins) :
            plugins;

        pluginsList.forEach(function (plugin) {
            var category = this._plugins[plugin.type];
            if (Array.isArray(category)) {
                category.push(plugin);
            } else {
                this._plugins[plugin.type] = [plugin];
            }
        }, this);
    },

    /**
     * @param {Object} data Information about the message from analyzers.
     * @returns {Promise}
     */
    process: function (data) {
        data = data || {};

        var bot = this._bot;
        var message = bot.getCurrentMessage();
        var plugins = this._plugins;
        var pluginsCategory = [].concat(plugins[data.type], plugins[MESSAGE_TYPES.ALL]).filter(Boolean);
        var information = {
            message: message,
            data: data
        };

        // If plugins not found in category.
        if (!pluginsCategory.length) {
            return vow.reject(new Error('Not found plugins for category'));
        }

        var plugin = pluginsCategory
            .filter(function (plugin) {
                var isCommand = data.type === MESSAGE_TYPES.COMMAND;
                // If we have bot name and get message in group chat like this:
                // `/start@myBot` -> we should not react on the message if bot name is not `myBot`.
                if (isCommand && data.commandFor && bot.getName()) {
                    return data.commandFor === bot.getName() && plugin.test(information);
                } else {
                    return plugin.test(information);
                }
            })
            .sort(function (a, b) {
                var aWeight = a.weight || 0;
                var bWeight = b.weight || 0;

                return b.weight - a.weight;
            })[0];

        // If we have not plugins, which match the message.
        if (!plugin) {
            return vow.reject(new Error('Have not plugins, which mathch the message'));
        }

        // Run plugin.
        var result;
        if (!bot.getUsersCollection()) {
            result = plugin.handler(information, bot);
            return isPromise(result) ?
                result :
                vow.resolve(result);
        } else {
            return bot.user.get().then(function (user) {
                information.user = user;
                return plugin.handler(information, bot);
            });
        }
    }
});

/**
 * @ignore
 * @param {String} pluginsDir
 * @param {IPlugin[]} [plugins=[]]
 * @returns {IPlugins[]} All plugins from `pluginsDir` folder.
 */
function getPlugins(pluginsDir, plugins) {
    plugins = plugins || [];
    fs.readdirSync(pluginsDir)
        .forEach(function (item) {
            var itemPath = path.resolve(pluginsDir, item);
            var stats = fs.statSync(itemPath);

            if (stats.isDirectory()) {
                getPlugins(itemPath, plugins);
            } else {
                var itemExtension = item.split('.').pop();
                if (itemExtension === 'js') {
                    plugins.push(require(itemPath));
                }
            }
        });

    return plugins;
}

function isPromise(value) {
    return value && typeof value.then === 'function';
}

module.exports = MessageController;
